// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Linq;
using System.Collections.Generic;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Svg;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;
using DsPdfWeb.Demos.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、SVG 画像を測定しレンダリングする方法を示しています。
    // なお、SVG が GcPdfGraphics にてレンダリングされる際、ラスタライズされないので、
    // SVG が拡大または縮小されても画質が保たれます。
    public class RenderSvg
    {
        public int CreatePDF(Stream stream)
        {
            // SVG を読み込みます。
            var svgPath = Path.Combine("Resources", "SvgMisc", "Pylo_Basic.svg");
            using var svg = GcSvgDocument.FromFile(svgPath);

            // 画像を測定しレンダリングします。
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            var pt = new PointF(g.Resolution, g.Resolution);
            var rc = new RectangleF(pt, svg.GetIntrinsicSize(SvgLengthUnits.Points));
            // SVG を描画し、その周囲にボーダーも描画します。
            g.DrawSvg(svg, pt);
            g.DrawRectangle(rc, Color.DarkGray);

            // 終了
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
